@@ -1,5 +1,15 @@
 from .AttrDict import AttrDict
 
+class TrackOptionsGitHub(AttrDict):
+    source: str
+
+    @classmethod
+    def expected_fields(cls, __type=True):
+        if __type:
+            return cls.__annotations__
+
+        return {k: v.__name__ for k, v in cls.__annotations__.items()}
+
 class TrackOptionsArchive(AttrDict):
     compression: str
 
@@ -13,6 +23,7 @@ class TrackOptionsArchive(AttrDict):
 class TrackOptions(AttrDict):
     archive: TrackOptionsArchive
     disableRemoteMetadata: bool
+    github: TrackOptionsGitHub
     
     @classmethod
     def expected_fields(cls, __type=True):
